@@ -299,12 +299,12 @@ from PPshare.news.news_baidu import (
 """
 新闻联播
 """
-from PPshare.xwlb import news_cctv
+from PPshare.special.xwlb import news_cctv
 
 """
 新经济
 """
-from PPshare.xjj import (
+from PPshare.special.xjj import (
     death_company,
     nicorn_company,
     maxima_company
@@ -354,4 +354,99 @@ from PPshare.energy.energy_carbon import (
 """
 energy_oil
 """
-from PPshare.energy.energy_oil_em import energy_oil_detail, energy_oil_hist
\ No newline at end of file
+from PPshare.energy.energy_oil_em import energy_oil_detail, energy_oil_hist
+"""
+空气-河北
+"""
+from PPshare.special.air.air_hebei import air_quality_hebei
+
+"""
+timeanddate-日出和日落
+"""
+from PPshare.special.air.time_and_date import sunrise_daily, sunrise_monthly
+"""
+air-quality
+"""
+from PPshare.special.air.air_zhenqi import (
+    air_quality_hist,
+    air_quality_rank,
+    air_quality_watch_point,
+    air_city_table,
+)
+"""
+奥运奖牌
+"""
+from PPshare.special.sport.sport_olympic import sport_olympic_hist
+"""
+冬奥会历届奖牌榜
+"""
+from PPshare.special.sport.sport_olympic_winter import sport_olympic_winter_hist
+
+"""
+汽车销量
+"""
+from PPshare.special.other.other_car import car_gasgoo_sale_rank, car_cpca_energy_sale
+"""
+世界五百强公司排名接口
+"""
+from PPshare.special.fortune.fortune_500 import fortune_rank, fortune_rank_eng
+"""
+福布斯中国榜单（代码需要优化，访问过于频繁，容易被ban）
+"""
+from PPshare.special.fortune.fortune_forbes_500 import forbes_rank
+
+"""
+胡润排行榜
+"""
+from PPshare.special.fortune.fortune_hurun import hurun_rank
+
+"""
+新财富富豪榜
+"""
+from PPshare.special.fortune.fortune_xincaifu_500 import xincaifu_rank
+"""
+电影票房
+"""
+from PPshare.special.movie.movie_yien import (
+    movie_boxoffice_cinema_daily,
+    movie_boxoffice_cinema_weekly,
+    movie_boxoffice_weekly,
+    movie_boxoffice_daily,
+    movie_boxoffice_monthly,
+    movie_boxoffice_realtime,
+    movie_boxoffice_yearly,
+    movie_boxoffice_yearly_first_week,
+)
+"""
+艺恩-视频放映
+"""
+from PPshare.special.movie.video_yien import video_variety_show, video_tv
+"""
+艺恩-艺人
+"""
+from PPshare.special.movie.artist_yien import (
+    online_value_artist,
+    business_value_artist,
+)
+"""
+中国电竞价值排行榜
+"""
+from PPshare.special.other.other_game import club_rank_game, player_rank_game
+"""
+成本-世界各大城市生活成本
+"""
+from PPshare.special.cost.cost_living import cost_living
+"""
+微博舆情报告
+"""
+from PPshare.special.stock_weibo_nlp import (
+    stock_js_weibo_nlp_time,
+    stock_js_weibo_report,
+)
+"""
+彭博亿万富豪指数（实时数据代码需要优化，访问频率过高，容易被ban）
+"""
+from PPshare.special.fortune.fortune_bloomberg import (
+    index_bloomberg_billionaires,
+    index_bloomberg_billionaires_hist,
+)
\ No newline at end of file
